==> jc-1.4.0.tar.gz: java/lang/ref/PhantomReference.h <==
// public class java.lang.ref.PhantomReference

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1f29b892f9e3a2d5 java_lang_ref_PhantomReference
// @dep_class 77273604094666c7 java_lang_ref_Reference

// header file dependencies
// @dep_header java_lang_ref_Reference

#include "java/lang/ref/Reference.h"

#ifndef _JC_java_lang_ref_PhantomReference_H_
#define _JC_java_lang_ref_PhantomReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_ReferenceQueue$object;

// Typedefs
typedef struct _jc_java_lang_ref_PhantomReference$sub_refs	_jc_java_lang_ref_PhantomReference$sub_refs;
typedef struct _jc_java_lang_ref_PhantomReference$sub_nonrefs	_jc_java_lang_ref_PhantomReference$sub_nonrefs;
typedef struct _jc_java_lang_ref_PhantomReference$refs	_jc_java_lang_ref_PhantomReference$refs;
typedef struct _jc_java_lang_ref_PhantomReference$nonrefs	_jc_java_lang_ref_PhantomReference$nonrefs;
typedef struct _jc_java_lang_ref_PhantomReference$object	_jc_java_lang_ref_PhantomReference$object;

typedef const struct _jc_java_lang_ref_PhantomReference$vmethods	_jc_java_lang_ref_PhantomReference$vmethods;
typedef const struct _jc_java_lang_ref_PhantomReference$vtable	_jc_java_lang_ref_PhantomReference$vtable;
typedef const struct _jc_java_lang_ref_PhantomReference$vtype	_jc_java_lang_ref_PhantomReference$vtype;

// Constructors
extern void _jc_java_lang_ref_PhantomReference$method$_init$5370f0fb4ab968c4(_jc_env *, struct _jc_java_lang_ref_PhantomReference$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_lang_ref_PhantomReference$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_ref_PhantomReference$method_info$get$a27f05608bfbd09b;

// Virtual methods structure
struct _jc_java_lang_ref_PhantomReference$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_lang_ref_PhantomReference$object *);
};

// Vtable
struct _jc_java_lang_ref_PhantomReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
	_jc_java_lang_ref_PhantomReference$vmethods	java_lang_ref_PhantomReference;
};

// Vtype
struct _jc_java_lang_ref_PhantomReference$vtype {
	_jc_type			type;
	_jc_java_lang_ref_PhantomReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_PhantomReference$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ref_PhantomReference$refs {
    _jc_java_lang_ref_PhantomReference$sub_refs	java_lang_ref_PhantomReference;
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_PhantomReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_PhantomReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
    _jc_java_lang_ref_PhantomReference$sub_nonrefs	java_lang_ref_PhantomReference;
};

// Object instance structure
struct _jc_java_lang_ref_PhantomReference$object {
	_jc_java_lang_ref_PhantomReference$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_PhantomReference$vtype	*vtype;
	_jc_java_lang_ref_PhantomReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_PhantomReference$vtype _jc_java_lang_ref_PhantomReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_PhantomReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_PhantomReference$class_object;

#endif	/* _JC_java_lang_ref_PhantomReference_H_ */

==> jc-1.4.6.tar.gz: java/lang/ref/PhantomReference.h <==
// public class java.lang.ref.PhantomReference

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1f29b892f9e3a2d5 java_lang_ref_PhantomReference
// @dep_class 77273604094666c7 java_lang_ref_Reference

// header file dependencies
// @dep_header java_lang_ref_Reference

#include "java/lang/ref/Reference.h"

#ifndef _JC_java_lang_ref_PhantomReference_H_
#define _JC_java_lang_ref_PhantomReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_ReferenceQueue$object;

// Typedefs
typedef struct _jc_java_lang_ref_PhantomReference$sub_refs	_jc_java_lang_ref_PhantomReference$sub_refs;
typedef struct _jc_java_lang_ref_PhantomReference$sub_nonrefs	_jc_java_lang_ref_PhantomReference$sub_nonrefs;
typedef struct _jc_java_lang_ref_PhantomReference$refs	_jc_java_lang_ref_PhantomReference$refs;
typedef struct _jc_java_lang_ref_PhantomReference$nonrefs	_jc_java_lang_ref_PhantomReference$nonrefs;
typedef struct _jc_java_lang_ref_PhantomReference$object	_jc_java_lang_ref_PhantomReference$object;

typedef const struct _jc_java_lang_ref_PhantomReference$vmethods	_jc_java_lang_ref_PhantomReference$vmethods;
typedef const struct _jc_java_lang_ref_PhantomReference$vtable	_jc_java_lang_ref_PhantomReference$vtable;
typedef const struct _jc_java_lang_ref_PhantomReference$vtype	_jc_java_lang_ref_PhantomReference$vtype;

// Constructors
extern void _jc_java_lang_ref_PhantomReference$method$_init$5370f0fb4ab968c4(_jc_env *, struct _jc_java_lang_ref_PhantomReference$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_lang_ref_PhantomReference$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_ref_PhantomReference$method_info$get$a27f05608bfbd09b;

// Virtual methods structure
struct _jc_java_lang_ref_PhantomReference$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_lang_ref_PhantomReference$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_ref_PhantomReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
	_jc_java_lang_ref_PhantomReference$vmethods	java_lang_ref_PhantomReference;
};

// Vtype
struct _jc_java_lang_ref_PhantomReference$vtype {
	_jc_type			type;
	_jc_java_lang_ref_PhantomReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_PhantomReference$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ref_PhantomReference$refs {
    _jc_java_lang_ref_PhantomReference$sub_refs	java_lang_ref_PhantomReference;
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_PhantomReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_PhantomReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
    _jc_java_lang_ref_PhantomReference$sub_nonrefs	java_lang_ref_PhantomReference;
};

// Object instance structure
struct _jc_java_lang_ref_PhantomReference$object {
	_jc_java_lang_ref_PhantomReference$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_PhantomReference$vtype	*vtype;
	_jc_java_lang_ref_PhantomReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_PhantomReference$vtype _jc_java_lang_ref_PhantomReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_PhantomReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_PhantomReference$class_object;

#endif	/* _JC_java_lang_ref_PhantomReference_H_ */
